---
name: Question, doubt or discussion
about: Create a report to initiate a discussion or get a question or doubt clarified
title: '[QUESTION/DISCUSSION]'
assignees: ''

---

<!--
In case, it's not an issue or feature request but you would like to do this:

- ask a question
- start a discussion
- clarify a doubt
- get inspiration

then please use this option.
-->
